@@ -3,15 +3,20 @@
 #' * `slope`     : linear regression slope
 #' * `slope_p`   : linear regression slope and p-value
 #' * `slope_mk`  : mann kendall Sen's slope and p-value
+#' * `slope_sen` : same as `slope_mk`, but with no p-value
 #' * `slope_boot`: bootstrap slope and p-value
 #'
 #' @param y vector of observations of length n, or a matrix with n rows.
 #' @param x vector of predictor of length n, or a matrix with n rows.
 #' @param fast Boolean. If true, [stats::.lm.fit()] will be used, which is 10x
 #' faster than [stats::lm()].
-#'
+#' @param ... ignored.
+#' 
 #' @return
-#' `slope` and `p-value` are returned.
+#' - `slope`  : linear regression coefficient
+#' - `pvalue` : `p-value <= 0.05`` means that corresponding `slope` is significant.
+#' - `sd`     : `Std. Error`
+#'
 #' For `slope_boot`, slope is estimated in many times. The lower, mean, upper
 #' and standard deviation (sd) are returned.
 #'
@@ -23,8 +28,8 @@
 #' r_boot <- slope_boot(y)
 #' @importFrom stats .lm.fit pt
 #' @export
-slope <- function(y, x){
-    # TODO: add tests for slopew
+slope <- function(y, x, ...){
+    # TODO: add tests for slop
     if (!is.matrix(y)) y <- as.matrix(y)
     n <- nrow(y)
 
@@ -69,13 +74,29 @@ slope_p <- function(y, x, fast = TRUE){
         l <- lm(y ~ x)
         coefficients <- summary(l)$coefficients
     }
-    coefficients[2, c(1, 4)] %>% set_names(c("slope", "pvalue"))
+    coefficients[2, c(1, 4, 2)] %>% set_names(c("slope", "pvalue", "sd"))
 }
 
 #' @rdname slope
 #' @export
-slope_mk <- function(x){
-    mkTrend(x)[c("slp", "pval")] %>% set_names(c("slope", "pvalue"))
+slope_sen_r <- function(y, x = seq_along(y), ...) {
+    n = length(x)
+    V <- rep(NA, times = (n^2 - n) / 2)
+    k = 0
+    for (i in 2:n) {
+        for (j in 1:(i - 1)) {
+            # for (j in 1:(n - 1)) {
+            k = k + 1
+            V[k] = (y[i] - y[j]) / (x[i] - x[j])
+        }
+    }
+    median(na.omit(V))
+}
+
+#' @rdname slope
+#' @export
+slope_mk <- function(y, x = NULL, ...){
+    mkTrend(y, x)[c("slp", "pval")] %>% set_names(c("slope", "pvalue"))
 }
 
 #' @param slope_FUN one of [slope()], [slope_p()], [slope_mk()]
@@ -89,14 +110,14 @@ slope_mk <- function(x){
 #' @importFrom boot boot
 #' @importFrom matrixStats colQuantiles colSds
 #' @export
-slope_boot <- function(y, slope_FUN = slope, times = 100, alpha = 0.1, seed) {
+slope_boot <- function(y, x = NULL, slope_FUN = slope, times = 100, alpha = 0.1, seed, ...) {
     if (!missing(seed)) set.seed(seed)
 
-    x0  <- seq_along(y)
+    x <- x %||% seq_along(y)
     FUN <- function(y0, indices) {
-        y <- y0[indices]
-        x <- x0[indices]
-        slope_FUN(y, x)
+        y2 <- y[indices]
+        x2 <- x[indices]
+        slope_FUN(y2, x2)
     }
     b <- boot(y, FUN, R = times)
 
